@@ -1,26 +1,27 @@
+use std::time::SystemTime;
+
 use http_signature_normalization_reqwest::prelude::*;
+use httpdate::HttpDate;
 use reqwest::{header::DATE, Client};
 use sha2::{Digest, Sha256};
-use time::OffsetDateTime;
 
 async fn request(config: Config) -> Result<(), Box<dyn std::error::Error>> {
     let digest = Sha256::new();
 
-    let response = Client::new()
+    let client = Client::new();
+
+    let request = client
         .post("http://127.0.0.1:8010/")
         .header("User-Agent", "Reqwest")
         .header("Accept", "text/plain")
-        .header(
-            DATE,
-            OffsetDateTime::now_utc().format("%a, %d %b %Y %H:%M:%S GMT"),
-        )
+        .header(DATE, HttpDate::from(SystemTime::now()).to_string())
         .signature_with_digest(config, "my-key-id", digest, "Hewwo-owo", |s| {
             println!("Signing String\n{}", s);
             Ok(base64::encode(s)) as Result<_, MyError>
         })
         .await?;
 
-    let body = response.bytes().await.map_err(MyError::Body)?;
+    let body = client.execute(request).await?.bytes().await?;
 
     println!("{:?}", body);
     Ok(())
